﻿using System;
using ELTE.Calculator.Device;
using Xamarin.Forms;

namespace ELTE.Calculator.View
{
    /// <summary>
    /// Tájolással kapcsolatos viselkedés StackLayout vezérlőre.
    /// </summary>
    public class StackLayoutOrientationBehavior : Behavior<StackLayout>
    {
        private IDeviceProperties _properties;

        public StackLayoutOrientationBehavior()
        {
            // lekérjük a függőség megfelelő megvalósítását
            _properties = DependencyService.Get<IDeviceProperties>();
        }

        protected override void OnAttachedTo(StackLayout bindable)
        {
            // feliratkozunk a méretváltozás eseményére
            bindable.SizeChanged += new EventHandler(Bindable_SizeChanged);

            // meg kell hívnunk az ős metódusát is
            base.OnAttachedTo(bindable);
        }

        protected override void OnDetachingFrom(StackLayout bindable)
        {
            // leiuratkozunk a méretváltozás eseményéről
            bindable.SizeChanged -= Bindable_SizeChanged;

            base.OnDetachingFrom(bindable);
        }

        private void Bindable_SizeChanged(object sender, EventArgs e)
        {
            if (_properties == null)
                return; // ha az adott platformon nem érhető el a függőség, nem csinálunk semmit

            StackLayout stackLayout = sender as StackLayout;

            // az eszköz tájolásának függvényében változtatunk a StackLayout tájolásán
            switch (_properties.DeviceOrientation)
            {
                case DeviceOrientation.Landscape:
                    if (stackLayout.Orientation != StackOrientation.Horizontal)
                        stackLayout.Orientation = StackOrientation.Horizontal;
                    break;
                case DeviceOrientation.Portrait:
                    if (stackLayout.Orientation != StackOrientation.Vertical)
                        stackLayout.Orientation = StackOrientation.Vertical;
                    break;
            }
        }

    }
}
